@@ -11,7 +11,6 @@ from pyrmv.raw.trip_find import trip_find as raw_trip_find
 from pyrmv.raw.trip_recon import trip_recon as raw_trip_recon
 from pyrmv.raw.him_search import him_search as raw_him_search
 from pyrmv.utility.find_exception import find_exception
-from pyrmv.errors.not_ready import NotReadyYetError
 
 try:
     from typing import Literal
@@ -19,20 +18,67 @@ except ImportError:
     from typing_extensions import Literal
 
 class Client():
+    """The main class in the whole module. Is used to use all non-raw methods.  
+
+    More detailed docs for each method can be found by using IDE's docstring
+    highlighting system or in project's wiki ([can be found here](https://git.end-play.xyz/profitroll/PythonRMV/wiki))
+
+    ### Args:
+        * access_id (`str`): Access ID for identifying the requesting client. Get your key on [RMV website](https://opendata.rmv.de/site/start.html).
+
+    ### Methods:
+        * board_arrival -> BoardArrival
+        * board_departure -> BoardDeparture
+        * him_search -> List[Message]
+        * journey_detail -> Journey
+        * stop_by_coords -> List[Stop]
+        * stop_by_id -> Union[Stop, None]
+        * stop_by_name -> List[Stop]
+        * trip_find -> List[Trip]
+        * trip_recon -> List[Trip]
+
+    ### Examples:
+    ```py
+    import pyrmv
+    from datetime import datetime, timedelta
+
+    # Create client object with you API key
+    client = pyrmv.Client("YourAccessId")
+
+    # Get arrival and departure boards for station "Frankfurt (Main) Taunusanlage"
+    board_arrival = client.board_arrival("A=1@O=Frankfurt (Main) Taunusanlage@X=8668765@Y=50113478@U=80@L=3000011@", journeys_max=5)
+    board_departure = client.board_departure("A=1@O=Frankfurt (Main) Taunusanlage@X=8668765@Y=50113478@U=80@L=3000011@", journeys_max=5)
+
+    # Search for HIM messages for S9
+    messages = client.him_search(date_end=datetime.now()+timedelta(days=10), priority_min=2, train_names=["S9"])
+
+    # Get detailed journey of Bus 101
+    journey = client.journey_detail("2|#VN#1#ST#1664906549#PI#0#ZI#12709#TA#0#DA#61022#1S#3008007#1T#1248#LS#3008043#LT#1323#PU#80#RT#1#CA#1aE#ZE#101#ZB#Bus 101 #PC#6#FR#3008007#FT#1248#TO#3008043#TT#1323#", real_time_mode=pyrmv.enums.RealTimeMode.FULL)
+
+    # Look for stops using all possible methods
+    stop_by_coords client.stop_by_coords(50.131140, 8.733362, radius=300, max_number=3)
+    stop_by_id = client.stop_by_id("A=1@O=Offenbach (Main)-Zentrum Marktplatz/Frankf. Straße@X=8764456@Y=50105181@U=80@L=3002510@")
+    stop_by_name = client.stop_by_name("Groß Karben", max_number=3)
+
+    # Find a trip and reconstruct it
+    trip = client.trip_find(origin_coord_lat="50.084659", origin_coord_lon="8.785948", destination_coord_lat=50.1233048, destination_coord_lon=8.6129742, messages=True)[0]
+    trip_recon = client.trip_recon(trip)[0]
+    ```  
+    """    
 
     def __init__(self, access_id: str) -> None:
         self.access_id = access_id
 
     def board_arrival(self,
-            id: str = None, # type: ignore
-            id_ext: str = None, # type: ignore
-            direction: Union[str, Stop, StopTrip] = None, # type: ignore
-            date: Union[str, datetime] = None, # type: ignore
-            time: Union[str, datetime] = None, # type: ignore
+            id: Union[str, None] = None,
+            id_ext: Union[str, None] = None,
+            direction: Union[str, Stop, StopTrip, None] = None,
+            date: Union[str, datetime, None] = None,
+            time: Union[str, datetime, None] = None,
             duration: Union[int, timedelta] = 60,
             journeys_max: int = -1,
-            operators: Union[str, list] = None, # type: ignore
-            lines: Union[str, list] = None, # type: ignore
+            operators: Union[str, list, None] = None,
+            lines: Union[str, list, None] = None,
             passlist: bool = False,
             board_type: Literal[BoardArrivalType.ARR, BoardArrivalType.ARR_EQUIVS, BoardArrivalType.ARR_MAST, BoardArrivalType.ARR_STATION] = BoardArrivalType.ARR,
         ) -> BoardArrival:
@@ -64,7 +110,7 @@ class Client():
             accessId=self.access_id,
             id=id,
             extId=id_ext,
-            direction=direction,
+            direction=direction, # type: ignore
             date=date,
             time=time,
             duration=duration,
@@ -80,15 +126,15 @@ class Client():
         return BoardArrival(board_raw, self)
 
     def board_departure(self,
-            id: str = None, # type: ignore
-            id_ext: str = None, # type: ignore
-            direction: Union[str, Stop, StopTrip] = None, # type: ignore
-            date: Union[str, datetime] = None, # type: ignore
-            time: Union[str, datetime] = None, # type: ignore
+            id: Union[str, None] = None,
+            id_ext: Union[str, None] = None,
+            direction: Union[str, Stop, StopTrip, None] = None,
+            date: Union[str, datetime, None] = None,
+            time: Union[str, datetime, None] = None,
             duration: Union[int, timedelta] = 60,
             journeys_max: int = -1,
-            operators: Union[str, list] = None, # type: ignore
-            lines: Union[str, list] = None, # type: ignore
+            operators: Union[str, list, None] = None,
+            lines: Union[str, list, None] = None,
             passlist: bool = False,
             board_type: Literal[BoardDepartureType.DEP, BoardDepartureType.DEP_EQUIVS, BoardDepartureType.DEP_MAST, BoardDepartureType.DEP_STATION] = BoardDepartureType.DEP,
         ) -> BoardDeparture:
@@ -120,7 +166,7 @@ class Client():
             accessId=self.access_id,
             id=id,
             extId=id_ext,
-            direction=direction,
+            direction=direction, # type: ignore
             date=date,
             time=time,
             duration=duration,
@@ -136,28 +182,28 @@ class Client():
         return BoardDeparture(board_raw, self)
 
     def him_search(self,
-            date_begin: Union[str, datetime] = None,
-            date_end: Union[str, datetime] = None,
-            time_begin: Union[str, datetime] = None,
-            time_end: Union[str, datetime] = None,
-            weekdays: Union[str, OrderedDict[str, bool]] = None,
-            ids: list = None,
-            operators: list = None,
-            categories: list = None,
-            channels: list = None,
-            companies: list = None,
-            lines: list = None,
-            line_ids: list = None,
-            stations: Union[list, List[Stop]] = None,
-            station_from: Union[str, Stop] = None,
-            station_to: Union[str, Stop] = None,
-            both_ways: bool = None,
-            train_names: list = None,
-            search_mode: Literal[SearchMode.MATCH, SearchMode.NOMATCH, SearchMode.TFMATCH] = None,
-            affected_journey_mode: Literal[AffectedJourneyMode.ALL, AffectedJourneyMode.OFF] = None,
-            affected_journey_stop_mode: Literal[AffectedJourneyStopMode.ALL, AffectedJourneyStopMode.IMP, AffectedJourneyStopMode.OFF] = None,
-            priority_min: int = None,
-            priority_max: int = None
+            date_begin: Union[str, datetime, None] = None,
+            date_end: Union[str, datetime, None] = None,
+            time_begin: Union[str, datetime, None] = None,
+            time_end: Union[str, datetime, None] = None,
+            weekdays: Union[str, OrderedDict[str, bool], None] = None,
+            ids: Union[list, None] = None,
+            operators: Union[list, None] = None,
+            categories: Union[list, None] = None,
+            channels: Union[list, None] = None,
+            companies: Union[list, None] = None,
+            lines: Union[list, None] = None,
+            line_ids: Union[list, None] = None,
+            stations: Union[list, List[Stop], None] = None,
+            station_from: Union[str, Stop, None] = None,
+            station_to: Union[str, Stop, None] = None,
+            both_ways: Union[bool, None] = None,
+            train_names: Union[list, None] = None,
+            search_mode: Union[Literal[SearchMode.MATCH, SearchMode.NOMATCH, SearchMode.TFMATCH], None] = None,
+            affected_journey_mode: Union[Literal[AffectedJourneyMode.ALL, AffectedJourneyMode.OFF], None] = None,
+            affected_journey_stop_mode: Union[Literal[AffectedJourneyStopMode.ALL, AffectedJourneyStopMode.IMP, AffectedJourneyStopMode.OFF], None] = None,
+            priority_min: Union[int, None] = None,
+            priority_max: Union[int, None] = None
         ) -> List[Message]:
         """The him_search method will deliver a list of HIM messages if matched by the given criteria as
         well as affected products if any.  
@@ -238,13 +284,13 @@ class Client():
             lines=lines,
             lineids=line_ids,
             stations=stations,
-            fromstation=station_from,
-            tostation=station_to,
+            fromstation=station_from, # type: ignore
+            tostation=station_to, # type: ignore
             bothways=both_ways,
             trainnames=train_names,
-            searchmode=search_mode,
-            affectedJourneyMode=affected_journey_mode,
-            affectedJourneyStopMode=affected_journey_stop_mode,
+            searchmode=search_mode, # type: ignore
+            affectedJourneyMode=affected_journey_mode, # type: ignore
+            affectedJourneyStopMode=affected_journey_stop_mode, # type: ignore
             maxprio=priority_max,
             minprio=priority_min
         )
@@ -258,12 +304,12 @@ class Client():
 
     def journey_detail(self,
             id: str,
-            date: Union[str, datetime] = None, # type: ignore
-            real_time_mode: Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT] = None, # type: ignore
-            from_id: str = None, # type: ignore
-            from_index: int = None, # type: ignore
-            to_id: str = None, # type: ignore
-            to_index: int = None # type: ignore
+            date: Union[str, datetime, None] = None,
+            real_time_mode: Union[Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT], None] = None,
+            from_id: Union[str, None] = None,
+            from_index: Union[int, None] = None,
+            to_id: Union[str, None] = None,
+            to_index: Union[int, None] = None
         ) -> Journey:
         """The journey_detail method will deliver information about the complete route of a vehicle. The journey
         identifier is part of a trip or `board_departure()` response. It contains a list of all stops/stations of this journey
@@ -294,7 +340,7 @@ class Client():
             accessId=self.access_id,
             id=id,
             date=date,
-            rtMode=real_time_mode,
+            rtMode=real_time_mode, # type: ignore
             fromId=from_id,
             fromIdx=from_index,
             toId=to_id,
@@ -313,7 +359,7 @@ class Client():
             radius: Union[int, float] = 1000,
             max_number: int = 10,
             stop_type: Literal[LocationType.S, LocationType.P, LocationType.SP, LocationType.SE, LocationType.SPE] = LocationType.S,
-            selection_mode: Literal[SelectionMode.SLCT_A, SelectionMode.SLCT_N] = None, # type: ignore
+            selection_mode: Union[Literal[SelectionMode.SLCT_A, SelectionMode.SLCT_N], None] = None,
         ) -> List[Stop]:
         """Method returns a list of stops around a given center coordinate.
         The returned results are ordered by their distance to the center coordinate.  
@@ -347,7 +393,7 @@ class Client():
             radius=radius,
             maxNo=max_number,
             stopType=stop_type.code,
-            locationSelectionMode=selection_mode
+            locationSelectionMode=selection_mode # type: ignore
         )
 
         find_exception(stops_raw)
@@ -371,7 +417,7 @@ class Client():
             * lang (`Literal[Language.DE, Language.DA, Language.EN, Language.ES, Language.FR, Language.HU, Language.IT, Language.NL, Language.NO, Language.PL, Language.SV, Language.TR]`, **optional**): The language of response. Defaults to `Language.EN`.
         
         ### Returns:
-            * Stop: Instance of `Stop` object or `None` if not found.
+            * Union[Stop, None]: Instance of `Stop` object or `None` if not found.
         """    
 
         stops_raw = raw_stop_by_name(
@@ -400,12 +446,12 @@ class Client():
             lang: Literal[Language.DE, Language.DA, Language.EN, Language.ES, Language.FR, Language.HU, Language.IT, Language.NL, Language.NO, Language.PL, Language.SV, Language.TR] = Language.EN,
             max_number: int = 10,
             stop_type: Literal[LocationType.A, LocationType.ALL, LocationType.AP, LocationType.P, LocationType.S, LocationType.SA, LocationType.SP] = LocationType.ALL,
-            selection_mode: Literal[SelectionMode.SLCT_A, SelectionMode.SLCT_N] = None, # type: ignore
-            coord_lat: Union[str, float] = None, # type: ignore
-            coord_lon: Union[str, float] = None, # type: ignore
+            selection_mode: Union[Literal[SelectionMode.SLCT_A, SelectionMode.SLCT_N], None] = None,
+            coord_lat: Union[str, float, None] = None,
+            coord_lon: Union[str, float, None] = None,
             radius: Union[int, float] = 1000,
-            refine_id: str = None, # type: ignore
-            stations: Union[str, list] = None, # type: ignore
+            refine_id: Union[str, None] = None,
+            stations: Union[str, list, None] = None,
             filter_mode: Literal[FilterMode.DIST_PERI, FilterMode.EXCL_PERI, FilterMode.SLCT_PERI] = FilterMode.DIST_PERI
         ) -> List[Stop]:
         """Method can be used to perform a pattern matching of a user input and to retrieve a list
@@ -443,7 +489,7 @@ class Client():
             lang=lang.code,
             maxNo=max_number,
             stopType=stop_type.code,
-            locationSelectionMode=selection_mode,
+            locationSelectionMode=selection_mode, # type: ignore
             coordLat=coord_lat,
             coordLong=coord_lon,
             radius=radius,
@@ -465,47 +511,47 @@ class Client():
     def trip_find(self,
             lang: Literal[Language.DE, Language.DA, Language.EN, Language.ES, Language.FR, Language.HU, Language.IT, Language.NL, Language.NO, Language.PL, Language.SV, Language.TR] = Language.EN,
 
-            origin_id: str = None, # type: ignore
-            origin_id_ext: str = None, # type: ignore
-            origin_coord_lat: Union[str, float] = None, # type: ignore
-            origin_coord_lon: Union[str, float] = None, # type: ignore
-            origin_coord_name: str = None, # type: ignore
+            origin_id: Union[str, None] = None,
+            origin_id_ext: Union[str, None] = None,
+            origin_coord_lat: Union[str, float, None] = None,
+            origin_coord_lon: Union[str, float, None] = None,
+            origin_coord_name: Union[str, None] = None,
 
-            destination_id: str = None, # type: ignore
-            destination_id_ext: str = None, # type: ignore
-            destination_coord_lat: Union[str, float] = None, # type: ignore
-            destination_coord_lon: Union[str, float] = None, # type: ignore
-            destination_coord_name: str = None, # type: ignore
+            destination_id: Union[str, None] = None,
+            destination_id_ext: Union[str, None] = None,
+            destination_coord_lat: Union[str, float, None] = None,
+            destination_coord_lon: Union[str, float, None] = None,
+            destination_coord_name: Union[str, None] = None,
 
-            via: str = None, # type: ignore
-            via_id: str = None, # type: ignore
-            via_gis: str = None, # type: ignore
+            via: Union[str, None] = None,
+            via_id: Union[str, None] = None,
+            via_gis: Union[str, None] = None,
             via_wait_time: int = 0,
 
-            avoid: str = None, # type: ignore
-            avoid_id: str = None, # type: ignore
+            avoid: Union[str, None] = None,
+            avoid_id: Union[str, None] = None,
 
             change_time_percent: int = 100,
-            change_time_min: int = None, # type: ignore
-            change_time_max: int = None, # type: ignore
-            change_time_add: int = None, # type: ignore
-            change_max: int = None, # type: ignore
+            change_time_min: Union[int, None] = None,
+            change_time_max: Union[int, None] = None,
+            change_time_add: Union[int, None] = None,
+            change_max: Union[int, None] = None,
 
-            date: Union[str, datetime] = None, # type: ignore
-            time: Union[str, datetime] = None, # type: ignore
+            date: Union[str, datetime, None] = None,
+            time: Union[str, datetime, None] = None,
             
             search_arrival: bool = False,
 
-            trips_after_time: int = None, # type: ignore
-            trips_before_time: int = None, # type: ignore
+            trips_after_time: Union[int, None] = None,
+            trips_before_time: Union[int, None] = None,
 
-            context: str = None, # type: ignore
+            context: Union[str, None] = None,
 
             passlist: bool = False,
-            operators: Union[str, list] = None, # type: ignore
+            operators: Union[str, list, None] = None,
             
-            lines: Union[str, list] = None, # type: ignore
-            lineids: Union[str, list] = None, # type: ignore
+            lines: Union[str, list, None] = None,
+            lineids: Union[str, list, None] = None,
 
             iv_include: bool = False,
             iv_only: bool = False,
@@ -514,11 +560,11 @@ class Client():
 
             passing_points: bool = False,
 
-            real_time_mode: Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT] = None, # type: ignore
+            real_time_mode: Union[Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT], None] = None,
 
             include_earlier: bool = False,
             ict_alternatives: bool = False,
-            tariff: bool = None, # type: ignore
+            tariff: Union[bool, None] = None,
             messages: bool = False,
             frequency: bool = True
         ) -> List[Trip]:
@@ -636,7 +682,7 @@ class Client():
 
             showPassingPoints=passing_points,
 
-            rtMode=real_time_mode,
+            rtMode=real_time_mode, # type: ignore
 
             includeEarlier=include_earlier,
             withICTAlternatives=ict_alternatives,
@@ -653,18 +699,18 @@ class Client():
         return trips
 
     def trip_recon(self,
-            context: Union[str, Journey],
-            date: Union[str, datetime] = None,
-            match_real_time: bool = None,
-            enable_replacements: bool = None,
-            arrival_dev_lower: int = None,
-            arrival_dev_upper: int = None,
-            departure_dev_lower: int = None,
-            departure_dev_upper: int = None,
-            passlist: bool = None,
+            context: Union[str, Trip],
+            date: Union[str, datetime, None] = None,
+            match_real_time: Union[bool, None] = None,
+            enable_replacements: Union[bool, None] = None,
+            arrival_dev_lower: Union[int, None] = None,
+            arrival_dev_upper: Union[int, None] = None,
+            departure_dev_lower: Union[int, None] = None,
+            departure_dev_upper: Union[int, None] = None,
+            passlist: bool = False,
             passing_points: bool = False,
-            real_time_mode: Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT] = None,
-            tariff: bool = None,
+            real_time_mode: Union[Literal[RealTimeMode.FULL, RealTimeMode.INFOS, RealTimeMode.OFF, RealTimeMode.REALTIME, RealTimeMode.SERVER_DEFAULT], None] = None,
+            tariff: Union[bool, None] = None,
             messages: bool = False
         ) -> List[Trip]:
         """Reconstructing a trip can be achieved using the reconstruction context provided by any trip result in the
@@ -703,7 +749,7 @@ class Client():
         trips = []
         trips_raw = raw_trip_recon(
             accessId=self.access_id,
-            ctx=context,
+            ctx=context, # type: ignore
             date=date,
             matchRtType=match_real_time,
             enableReplacements=enable_replacements,
@@ -713,7 +759,7 @@ class Client():
             depU=departure_dev_upper,
             passlist=passlist,
             showPassingPoints=passing_points,
-            rtMode=real_time_mode,
+            rtMode=real_time_mode, # type: ignore
             tariff=tariff,
             trafficMessages=messages,
         )
