@@ -2,7 +2,7 @@
 # https://github.com/pyrogram/pyrogram/blob/master/pyrogram/enums/auto_name.py
 
 from enum import Enum
-from const.product import PRODUCTS
+from pyrmv.const.product import PRODUCTS
 
 class AutoName(Enum):
     def __init__(self, code) -> None:
