@@ -11,19 +11,19 @@ except ImportError:
 # 2.25. Arrival Board (arrivalBoard)
 def board_arrival(accessId: str,
         json: bool = True,
-        id: str = None, # type: ignore
-        extId: str = None, # type: ignore
-        direction: str = None, # type: ignore
-        date: Union[str, datetime] = None, # type: ignore
-        time: Union[str, datetime] = None, # type: ignore
-        duration: int = 60,
+        id: Union[str, None] = None,
+        extId: Union[str, None] = None,
+        direction: Union[str, None] = None,
+        date: Union[str, datetime, None] = None,
+        time: Union[str, datetime, None] = None,
+        duration: Union[int, timedelta] = 60,
         maxJourneys: int = -1,
-        products: int = None, # type: ignore
-        operators: Union[str, list] = None, # type: ignore
-        lines: Union[str, list] = None, # type: ignore
+        products: Union[int, None] = None,
+        operators: Union[str, list, None] = None,
+        lines: Union[str, list, None] = None,
         filterEquiv: bool = True,
-        attributes: Union[str, list] = None, # type: ignore
-        platforms: Union[str, list] = None, # type: ignore
+        attributes: Union[str, list, None] = None,
+        platforms: Union[str, list, None] = None,
         passlist: bool = False,
         boardType: Literal["ARR", "ARR_EQUIVS", "ARR_MAST", "ARR_STATION"] = "ARR"
     ) -> dict:
@@ -81,7 +81,7 @@ def board_arrival(accessId: str,
         elif str(var) == "duration":
             if val != None:
                 if isinstance(val, timedelta):
-                    payload[str(var)] = val.minutes
+                    payload[str(var)] = val.minutes # type: ignore
                 else:
                     payload[str(var)] = val
         elif str(var) == "boardType":
@@ -93,10 +93,6 @@ def board_arrival(accessId: str,
 
     output = get("https://www.rmv.de/hapi/arrivalBoard", params=payload, headers=headers)
 
-    # Exceptions checker moved to normal methods
-    # and exceptions will no longer raise in raw ones.
-    # find_exception(output.json())
-
     if json:
         return output.json()
     else:
