@@ -13,87 +13,87 @@ def trip_find(accessId: str,
         lang: Literal["de", "da", "en", "es", "fr", "hu", "it", "nl", "no", "pl", "sv", "tr"] = "en",
         json: bool = True,
 
-        originId: str = None, # type: ignore
-        originExtId: str = None, # type: ignore
-        originCoordLat: Union[str, float] = None, # type: ignore
-        originCoordLong: Union[str, float] = None, # type: ignore
-        originCoordName: str = None, # type: ignore
+        originId: Union[str, None] = None,
+        originExtId: Union[str, None] = None,
+        originCoordLat: Union[str, float, None] = None,
+        originCoordLong: Union[str, float, None] = None,
+        originCoordName: Union[str, None] = None,
 
-        destId: str = None, # type: ignore
-        destExtId: str = None, # type: ignore
-        destCoordLat: Union[str, float] = None, # type: ignore
-        destCoordLong: Union[str, float] = None, # type: ignore
-        destCoordName: str = None, # type: ignore
+        destId: Union[str, None] = None,
+        destExtId: Union[str, None] = None,
+        destCoordLat: Union[str, float, None] = None,
+        destCoordLong: Union[str, float, None] = None,
+        destCoordName: Union[str, None] = None,
 
-        via: str = None, # type: ignore
-        viaId: str = None, # type: ignore
+        via: Union[str, None] = None,
+        viaId: Union[str, None] = None,
         viaWaitTime: int = 0,
 
-        avoid: str = None, # type: ignore
-        avoidId: str = None, # type: ignore
+        avoid: Union[str, None] = None,
+        avoidId: Union[str, None] = None,
 
-        viaGis: str = None, # type: ignore
+        viaGis: Union[str, None] = None,
 
         changeTimePercent: int = 100,
-        minChangeTime: int = None, # type: ignore
-        maxChangeTime: int = None, # type: ignore
-        addChangeTime: int = None, # type: ignore
-        maxChange: int = None, # type: ignore
+        minChangeTime: Union[int, None] = None,
+        maxChangeTime: Union[int, None] = None,
+        addChangeTime: Union[int, None] = None,
+        maxChange: Union[int, None] = None,
 
-        date: Union[str, datetime] = None, # type: ignore
-        time: Union[str, datetime] = None, # type: ignore
+        date: Union[str, datetime, None] = None,
+        time: Union[str, datetime, None] = None,
         
         searchForArrival: bool = False,
 
-        numF: int = None, # type: ignore
-        numB: int = None, # type: ignore
+        numF: Union[int, None] = None,
+        numB: Union[int, None] = None,
 
-        context: str = None, # type: ignore
+        context: Union[str, None] = None,
 
         poly: bool = False,
         polyEnc: Literal["DLT", "GPA", "N"] = "N",
 
         passlist: bool = False,
-        products: int = None, # type: ignore
-        operators: Union[str, list] = None, # type: ignore
+        products: Union[int, None] = None,
+        operators: Union[str, list, None] = None,
         
-        attributes: Union[str, list] = None, # type: ignore
-        sattributes: Union[str, list] = None, # type: ignore
-        fattributes: Union[str, list] = None, # type: ignore
-        lines: Union[str, list] = None, # type: ignore
-        lineids: Union[str, list] = None, # type: ignore
+        attributes: Union[str, list, None] = None,
+        sattributes: Union[str, list, None] = None,
+        fattributes: Union[str, list, None] = None,
+        lines: Union[str, list, None] = None,
+        lineids: Union[str, list, None] = None,
 
-        avoidPaths: List[Literal["SW", "EA", "ES", "RA", "CB"]] = None, # type: ignore
+        avoidPaths: Union[List[Literal["SW", "EA", "ES", "RA", "CB"]], None] = None,
 
-        originWalk: Union[str, list] = None, # type: ignore
-        originBike: Union[str, list] = None, # type: ignore
-        originCar: Union[str, list] = None, # type: ignore
-        originTaxi: Union[str, list] = None, # type: ignore
-        originPark: Union[str, list] = None, # type: ignore
-        originMeta: Union[str, list] = None, # type: ignore
+        originWalk: Union[str, list, None] = None,
+        originBike: Union[str, list, None] = None,
+        originCar: Union[str, list, None] = None,
+        originTaxi: Union[str, list, None] = None,
+        originPark: Union[str, list, None] = None,
+        originMeta: Union[str, list, None] = None,
 
-        destWalk: Union[str, list] = None, # type: ignore
-        destBike: Union[str, list] = None, # type: ignore
-        destCar: Union[str, list] = None, # type: ignore
-        destTaxi: Union[str, list] = None, # type: ignore
-        destPark: Union[str, list] = None, # type: ignore
-        destMeta: Union[str, list] = None, # type: ignore
+        destWalk: Union[str, list, None] = None,
+        destBike: Union[str, list, None] = None,
+        destCar: Union[str, list, None] = None,
+        destTaxi: Union[str, list, None] = None,
+        destPark: Union[str, list, None] = None,
+        destMeta: Union[str, list, None] = None,
 
-        totalWalk: Union[str, list] = None, # type: ignore
-        totalBike: Union[str, list] = None, # type: ignore
-        totalCar: Union[str, list] = None, # type: ignore
-        totalTaxi: Union[str, list] = None, # type: ignore
-        totalMeta: Union[str, list] = None, # type: ignore
+        totalWalk: Union[str, list, None] = None,
+        totalBike: Union[str, list, None] = None,
+        totalCar: Union[str, list, None] = None,
+        totalTaxi: Union[str, list, None] = None,
+        totalMeta: Union[str, list, None] = None,
 
-        gisProducts: str = None, # type: ignore
+        gisProducts: Union[str, None] = None,
 
         includeIv: bool = False,
         ivOnly: bool = False,
 
-        mobilityProfile: str = None, # type: ignore
+        mobilityProfile: Union[str, None] = None,
         
         bikeCarriage: bool = False,
-        bikeCarriageType: Literal["SINGLEBIKES", "SMALLGROUPS", "LARGEGROUPS"] = None, # type: ignore
+        bikeCarriageType: Union[Literal["SINGLEBIKES", "SMALLGROUPS", "LARGEGROUPS"], None] = None,
 
         sleepingCar: bool = False,
         couchetteCoach: bool = False,
@@ -102,24 +102,24 @@ def trip_find(accessId: str,
 
         eco: bool = False,
         ecoCmp: bool = False,
-        ecoParams: str = None, # type: ignore
+        ecoParams: Union[str, None] = None,
 
-        rtMode: Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"] = None, # type: ignore
+        rtMode: Union[Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"], None] = None,
 
         unsharp: bool = False,
-        trainFilter: str = None, # type: ignore
+        trainFilter: Union[str, None] = None,
         economic: bool = False,
-        groupFilter: str = None, # type: ignore
+        groupFilter: Union[str, None] = None,
 
-        blockingList: str = None, # type: ignore
-        blockedEdges: str = None, # type: ignore
+        blockingList: Union[str, None] = None,
+        blockedEdges: Union[str, None] = None,
 
         trainComposition: bool = False,
         includeEarlier: bool = False,
         withICTAlternatives: bool = False,
-        tariff: bool = None, # type: ignore
+        tariff: Union[bool, None] = None,
         trafficMessages: bool = False,
-        travellerProfileData: str = None, # type: ignore
+        travellerProfileData: Union[str, None] = None,
         withFreq: bool = True
     ) -> dict:
     """The trip service calculates a trip from a specified origin to a specified destination. These might be
@@ -248,10 +248,6 @@ def trip_find(accessId: str,
 
     output = get("https://www.rmv.de/hapi/trip", params=payload, headers=headers)
 
-    # Exceptions checker moved to normal methods
-    # and exceptions will no longer raise in raw ones.
-    # find_exception(output.json())
-
     if json:
         return output.json()
     else:
